@@ -7,22 +7,21 @@ PerlIO::excl - Creates a file only if it doesn't exist
 
 =head1 SYNOPSIS
 
-	open my $io,  '+< :creat :excl', $file;
+	open my $io,  '+<:excl', $file;
 
 =head1 DESCRIPTION
 
-C<PerlIO::excl> appends O_EXCL to the open flags.
+C<PerlIO::excl> appends C<O_EXCL> to the open flags.
 
 When you'd like to create a file only if it doesn't exist before, you
-can use the C<:excl> layer and the C<:creat> layer with an open mode
-'<' or '+<'.
+can use the C<:excl> layer.
+
+This is a pseudo layer that doesn't be pushed on the layer stack.
 
 =head1 SEE ALSO
 
 L<PerlIO::Util>.
 
-L<PerlIO::creat>.
-
 L<perlfunc/sysopen>.
 
 =head1 AUTHOR
