@@ -15,7 +15,7 @@ PerlIO::flock - Easy flock() interface
 
 =head1 DESCRIPTION
 
-The C<:flock> layer provides an interface to C<flock()>.
+C<PerlIO::flock> provides an interface to C<flock()>.
 
 It tries to lock the filehandle with C<flock()> according to the open mode.
 That is, if a file is opened for writing, C<:flock> attempts exclusive lock
@@ -25,15 +25,17 @@ It waits until the lock is granted. If an argument C<non-blocking> (or
 C<LOCK_NB>) is suplied, the call of C<open()> (or C<binmode()>) fails when
 the lock cannot be granted.
 
+This is a pseudo layer that doesn't be pushed on the layer stack.
+
 =head1 EXAMPLE
 
 	# tries shared lock, or waits until the lock is granted
-	open IN, "<:flock", $file;
-	open IN, "<:flock(blocking)", $file;     # ditto.
+	open my $in, "<:flock", $file;
+	open my $in, "<:flock(blocking)", $file;     # ditto.
 
 	# tries shared lock, or returns undef
-	open IN, "<:flock(non-blocking)", $file; 
-	open IN, "<:flock(LOCK_NB)", $file;      # ditto.
+	open my $in, "<:flock(non-blocking)", $file; 
+	open my $in, "<:flock(LOCK_NB)", $file;      # ditto.
 
 =head1 SEE ALSO
 
